@@ -2,6 +2,7 @@ from pythontools.core import logger
 from threading import Thread
 import traceback
 
+
 class Event:
 
     def __init__(self, name, function, scope="global", threaded=False):
@@ -16,21 +17,25 @@ class Event:
         else:
             self.function(*args, **kwargs)
 
+
 events = []
 
+
 def registerEvent(event):
     events.append(event)
 
+
 def unregisterEvent(event):
     for e in events:
         if e == event:
             events.remove(e)
 
+
 def call(name, *args, scope="global", **kwargs):
     try:
         for event in events:
             if event.name == name and event.scope == scope:
                 event.call(*args, **kwargs)
     except Exception as e:
-        logger.log("§cEvent '" + name + "' throw exception: " + str(e))
+        logger.log(f"§cEvent '{name}' throw exception: {e}")
         traceback.print_exc()
\ No newline at end of file
