@@ -121,7 +121,7 @@ def _replaceColors(message):
     return message
 
 def log(message):
-    message = "§!r§f[" + time.strftime(timeFormat, time.localtime()) + "] §!r" + message + "§!r"
+    message = f"§!r§f[{time.strftime(timeFormat, time.localtime())}] §!r{message}§!r"
     logs.append(message)
     try: tools.appendToFile(logFile, message)
     except: pass
@@ -129,11 +129,11 @@ def log(message):
     print(message)
 
 def userInput(message, password=False, strip=True):
-    message = "§!r§f[" + time.strftime(timeFormat, time.localtime()) + "] §!r" + message + "§!r"
+    message = f"§!r§f[{time.strftime(timeFormat, time.localtime())}] §!r{message}§!r"
     message = _replaceColors(message)
     if password is True:
         response = str(stdiomask.getpass(prompt=message))
         return response.strip() if strip is True else response
     else:
         print(message, end="")
-        return input().strip() if strip is True else input()
\ No newline at end of file
+        return input().strip() if strip is True else input()
