@@ -3,6 +3,7 @@ import requests
 TELEGRAM_TOKEN = None
 TELEGRAM_CHAT_ID = None
 
+
 def setToken(TOKEN):
     global TELEGRAM_TOKEN
     TELEGRAM_TOKEN = TOKEN
@@ -13,4 +14,4 @@ def setChatID(CHAT_ID):
 
 def sendMessage(message, chat_id=None):
     global TELEGRAM_TOKEN, TELEGRAM_CHAT_ID
-    requests.post('https://api.telegram.org/bot' + str(TELEGRAM_TOKEN) + '/sendMessage', data={'chat_id': chat_id if chat_id is not None else TELEGRAM_CHAT_ID, 'text': message, 'parse_mode': "Markdown"})
\ No newline at end of file
+    requests.post(f'https://api.telegram.org/bot{TELEGRAM_TOKEN}/sendMessage', data={'chat_id': chat_id if chat_id is not None else TELEGRAM_CHAT_ID, 'text': message, 'parse_mode': "Markdown"})
\ No newline at end of file
